# Using tRPC with Next.js 14, React Query and Prisma

In this comprehensive guide, we will explore the process of integrating tRPC, React Query v5, and Prisma within the Next.js 14 App Router. tRPC is a modern RPC framework that allows you to define your API using TypeScript interfaces and generates both server and client code for you. 

![Using tRPC with Next.js 14, React Query and Prisma](https://codevoweb.com/wp-content/uploads/2024/01/Using-tRPC-with-Next.js-14-React-Query-and-Prisma.webp)

### Topics Covered

- Bootstrapping the Next.js 14 Project
- Setting up PostgreSQL with Docker
- Setting up Prisma ORM
- Setting up tRPC Client and Server
  - Creating React Query Client
  - Initializing tRPC Server
  - Creating the tRPC API
  - Initializing the tRPC Client
  - Creating the tRPC Provider
- Testing the tRPC Server and Client
- Creating the tRPC Backend
  - Creating Validation Schemas
  - Creating tRPC Procedure Handlers
  - Creating tRPC Router
  - Merging tRPC Routers
- Creating the tRPC Frontend
  - Performing Query with tRPC
  - Performing Mutation with tRPC
  - Prefetching Data with tRPC and React Query
- Conclusion

Read the entire article here: [https://codevoweb.com/using-trpc-with-nextjs-14-react-query-and-prisma/](https://codevoweb.com/using-trpc-with-nextjs-14-react-query-and-prisma/)
